/* IFTIME - Batch file oriented time comparison utility */
/* (c) copyright 1991 John M. Hughes                    */

#include <stdio.h>
#include <string.h>
#include <time.h>
#include <dos.h>
#include <math.h>

typedef char msgline[52];
const  msgline msg[14] = {
           "\n",
           "iftime - (c) 1991 John M. Hughes - Public Domain\n",
           "\n",
           "Usage: iftime [test time]\n",
           "\n",
           "       [test time] = HH:MM (use 0's if nesc.) \n",
           "                     example: iftime 03:05    \n",
           "\n",
           "       Returns 0 if current time = test time  \n",
           "               1 if current time < test time  \n",
           "               2 if current time > test time  \n",
           "               3 if test time value invalid   \n",
           "               4 if command line invalid      \n",
           "\n"};


/* TST_TIME */
int tst_time(unsigned int hour, unsigned int min) 
{
  struct time t;
  unsigned int tstval,sysval;

  tstval = (hour * 60) + (min);

  /* see if value is bogus - max value is HH*60 + MM = 1439 or 23:59 */
  if (tstval > 1439) {
     printf("Invalid time value\n");
     return 3;
     }

  /* convert current system time to unsigned integer */
  gettime(&t);
  sysval = (t.ti_hour * 60) + t.ti_min;

  if (sysval == tstval)
     return 0;
  if (sysval < tstval)
     return 1;
  return 2;       /* assume sysval > tstval */
}


/* MAIN */
void main (int argc, char *argv[])
{
  int   cnt;
  char  hr[3];
  char  mn[3];
  char  *mnpt;
  unsigned int hrval,mnval;

  /* display usage message if command line malformed */
  if (argc != 2) {
     for (cnt=0; cnt < 14; cnt++)
        printf("%s",msg[cnt]);
     exit(4);
     }

  /* parse out minutes and seconds strings - this is clumsy and requires
     fixed-length time strings. It could be improved. */

  mnpt = &argv[1][3];
  strncpy(hr,argv[1],2);
  strncpy(mn,mnpt,2);

  /* convert hours and minutes to int values */

  hrval = (unsigned) atol(hr);
  mnval = (unsigned) atol(mn);

  /* compare values and set exit code */

  exit(tst_time(hrval,mnval));
}

